@@ -23,6 +23,7 @@ coef( summary( estResult ), logSigma = FALSE )
 margEff( estResult )
 summary( margEff( estResult ) )
 logLik( estResult )
+nobs( estResult )
 extractAIC( estResult )
 formula( estResult )
 model.frame( estResult )
@@ -83,6 +84,7 @@ summary( margEff( estResultStart, calcVCov = FALSE, returnJacobian = TRUE ) )
 maxLik:::summary.maxLik( estResultStart )
 summary( estResultStart )
 logLik( estResultStart )
+nobs( estResultStart )
 formula( estResultStart )
 
 ## estimation with left-censoring at 5
@@ -100,6 +102,7 @@ coef( estResultAdd, logSigma = FALSE )
 vcov( estResultAdd )
 vcov( estResultAdd, logSigma = FALSE )
 logLik( estResultAdd )
+nobs( estResultAdd )
 extractAIC( estResultAdd )
 
 ## estimation with right-censoring
@@ -117,6 +120,7 @@ coef( estResultNeg, logSigma = FALSE )
 vcov( estResultNeg )
 vcov( estResultNeg, logSigma = FALSE )
 logLik( estResultNeg )
+nobs( estResultNeg )
 extractAIC( estResultNeg )
 model.frame( estResultNeg )
 
@@ -135,6 +139,7 @@ coef( estResultAddNeg, logSigma = FALSE )
 vcov( estResultAddNeg )
 vcov( estResultAddNeg, logSigma = FALSE )
 logLik( estResultAddNeg )
+nobs( estResultAddNeg )
 extractAIC( estResultAddNeg )
 
 ## estimation with left and right censoring
@@ -153,6 +158,7 @@ vcov( estResultBoth, logSigma = FALSE )
 coef( summary( estResultBoth ) )
 coef( summary( estResultBoth ), logSigma = FALSE )
 logLik( estResultBoth )
+nobs( estResultBoth )
 extractAIC( estResultBoth )
 estfun( estResultBoth )[ 20 * c(1:30), ]
 meat( estResultBoth )
